.. include:: ../references.txt

.. _api_utils:

*****************
utils - Utilities
*****************

.. currentmodule:: gammapy.utils

.. automodapi:: gammapy.utils.coordinates
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.utils.integrate
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.utils.interpolation
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.utils.fits
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.utils.random
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.utils.regions
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.utils.scripts
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.utils.table
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.utils.testing
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.utils.time
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.utils.units
    :no-inheritance-diagram:
    :include-all-objects:
